#!/usr/bin/env python
# -*- coding: utf-8 -*-
from PyQt4 import QtCore
from PyQt4.QtGui import QApplication
from ui.calcstub import MainWindow

if __name__ == "__main__":
    import sys
    app = QApplication(sys.argv)
    ui = MainWindow()
    ui.show()
    sys.exit(app.exec_())
